
//*******************************************************************************************
//-This file is simple demonstration application for receiving data from BBMagic FLOOD sensor
//-You can run it on Raspberry Pi zero W or Raspberry Pi 3 with Bluetooth Low Energy
//-to see more visit: www.bbmagic.net
//-Copyright 2018 BBMagic Project ; see: _BBM_GNU_GPL_COPYING.txt
//*******************************************************************************************
//-Ten plik jest prost aplikacj demonstracyjn odbierajc dane z sensora BBMagic FLOOD
//-do uruchomienia na Raspberry Pi zero W lub Raspberry Pi 3 z Bluetooth Low Energy
//-aby dowiedzie si wicej zobacz: www.bbmagic.net
//-Copyright 2018 BBMagic Project ; zobacz: _BBM_GNU_GPL_COPYING.txt
//*******************************************************************************************


#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include "bbmagic_lib.h"


//*******************************************************************************************
//-START APP
//*******************************************************************************************
int main(void)
{
    unsigned char bbm_buf[BBLIB_FRAME_SIZE] ;
    int i, data_length ;
    float vcc_f ;


    printf("\n\n\t*** BBMAGIC FLOOD TEST ***\n") ;
    printf("\t***  www.bbmagic.net  ***\n") ;
    printf("\t*** hit ctrl+C to stop ***\n\n") ;

    i = bbm_bt_lib_version() ;
    printf("bbm_lib_version: %0.4X - ",i) ;
    if(i == 0x0102) printf("ok\n") ;
    else
    {
        printf("nok - stop\n\n") ;
        exit(1) ;
    }

    i = bbm_bt_open(17) ;
    if(i) exit(2) ;

    do
    {
        data_length = bbm_bt_read(bbm_buf) ;
        if(data_length > 0)
        {
            switch(bbm_buf[BBMAGIC_DEVICE_TYPE])
            {
                case BBMAGIC_M_FLOOD :

                    printf("BBM_FLOOD_") ;
                    //- BT address - 6 B
                    for(i=0; i<BBM_BT_ADDR_SIZE; i++) printf("%0.2X", bbm_buf[BBMAGIC_DEVICE_ADDR_5 + i]) ;

                    //-firm version
                    //printf(" | firm.%0.2X.%0.2X >\n",bbm_buf[BBM_FLOOD_FIRM_1], bbm_buf[BBM_FLOOD_FIRM_0]) ;

                    //- vcc
                    vcc_f = (float)bbm_buf[BBM_FLOOD_V_SUP] ; vcc_f/=BBMAGIC_VCC_DIVIDER ;       //-calculate power suuply voltage
                    printf(" | %0.2fV", vcc_f) ;

                    //-working time
                    i =bbm_buf[BBM_FLOOD_WORKTIME_3] ; i<<=8 ; i |=bbm_buf[BBM_FLOOD_WORKTIME_2] ; i<<=8 ;
                    i |=bbm_buf[BBM_FLOOD_WORKTIME_1] ; i<<=8 ; i |=bbm_buf[BBM_FLOOD_WORKTIME_0] ;
                    printf(" | %4d",i) ;

                    //-RSSI
                    printf(" | %ddBm | ", (signed char)bbm_buf[BBMAGIC_DEVICE_RSSI]) ;     //-RSSI

                    //-ALERT or ALIVE
                    if(bbm_buf[BBM_FLOOD_ALERT_FLAGS] & BBM_FLOOD_ALERT_MASK) printf(" FLOOD ALERT !!") ;
                    else printf(" NO FLOOD :-)") ;
                break ;

                default:
                    printf("BBM_UNKNOWN_") ;
                    //-BT address - 6 B
                    for(i=0; i<BBM_BT_ADDR_SIZE; i++) printf("%0.2X", bbm_buf[BBMAGIC_DEVICE_ADDR_5 + i]) ;

                    printf(" BBM_TYPE=%0.2X", bbm_buf[BBMAGIC_DEVICE_TYPE]) ;
                break ;
            } ;
            printf("\n") ;
        }
        usleep(100) ;
    }while(data_length != -1) ;

    bbm_bt_close() ;

    exit(0) ;
}

